@@ -15,7 +15,7 @@
 #'
 #' @param ndr_container The purpose of this argument is to make the
 #'   constructor of the cv_standard cross-validator work with the magrittr
-#'   pipe (%>%) operator. This argument would almost always be set at the
+#'   pipe (|>) operator. This argument would almost always be set at the
 #'   end of a sequence of piping operators that include a datasource and a 
 #'   classifier. Alternatively, one can keep this set to NULL and directly use
 #'   the datasource and classifier arguments (one would almost never use
@@ -216,6 +216,10 @@ new_cv_standard <- function(datasource,
   
   
   if (is.null(result_metrics)) {
+    
+    warning(paste("The result_metrics argument is NULL in the cv_standard constructor.", 
+                   "Setting the result_metrics to default values of rm_main_results and rm_confusion_matrix."))
+    
     result_metrics <- list(
       rm_main_results(),
       rm_confusion_matrix())
@@ -303,11 +307,11 @@ run_decoding.cv_standard <- function(cv_obj) {
   # Do a parallel loop over resample runs
   iResample <- 0  # to deal with an R check note
   all_resample_run_decoding_results <- list() 
-  all_resample_run_decoding_results <- foreach(iResample = 1:num_resample_runs, 
+  all_resample_run_decoding_results <- foreach(iResample = 1:num_resample_runs,
                                                .options.snow=opts) %do_type% { 
 
     
-    message(paste0("Start resample run: ", strrep(" ", 3 - nchar(as.character(iResample))),  iResample, 
+    message(paste0("\nStart resample run: ", strrep(" ", 3 - nchar(as.character(iResample))),  iResample, 
                      "   Start time: ",  Sys.time()))
     
     
@@ -338,10 +342,10 @@ run_decoding.cv_standard <- function(cv_obj) {
 
         training_set <- dplyr::filter(
           cv_data, .data$time_bin == unique_times[iTrain],
-          all_cv_train_test_inds[iCV] == "train") %>%
+          all_cv_train_test_inds[iCV] == "train") |>
           dplyr::select(starts_with("site"), .data$train_labels)
 
-        test_set <- dplyr::filter(cv_data, all_cv_train_test_inds[iCV] == "test") %>%
+        test_set <- dplyr::filter(cv_data, all_cv_train_test_inds[iCV] == "test") |>
           dplyr::select(starts_with("site"), .data$test_labels, .data$time_bin)
 
         if (!run_TCD) {
@@ -363,8 +367,8 @@ run_decoding.cv_standard <- function(cv_obj) {
         curr_cv_prediction_results <- get_predictions(classifier, training_set, test_set)
 
         # add the current CV run number, train time to the results data frame
-        curr_cv_prediction_results <- curr_cv_prediction_results %>%
-          dplyr::mutate(CV = iCV, train_time = unique_times[iTrain]) %>%
+        curr_cv_prediction_results <- curr_cv_prediction_results |>
+          dplyr::mutate(CV = iCV, train_time = unique_times[iTrain]) |>
           select(.data$CV, .data$train_time, everything())
 
         # all_cv_results <- rbind(all_cv_results, curr_cv_prediction_results)
