@@ -136,7 +136,9 @@ read_raster_data <- function(raster_file_name) {
 #' @param add_sequential_trial_numbers A Boolean specifying one should add a
 #'   variable to the data called 'trial_number' that has sequential trial. These
 #'   trials numbers are needed for data that was recorded simultaneously so that
-#'   trials can be aligned across different sites.
+#'   trials can be aligned across different sites. If the MATLAB raster data has
+#'   a field site_info.trial_number then this will override the trial_number that
+#'   would automatically be set to that value (and print a message about it). 
 #'
 #' @inherit read_raster_data return 
 #' 
@@ -318,6 +320,27 @@ read_matlab_raster_data <- function(matlab_raster_file_name,
   
   
   
+  # If there is a variable site_info.trial_number convert it to be just trial_number
+  # Also make trial_number the first column
+  if ("site_info.trial_number" %in% names(raster_data)) {
+    
+    # if specified, add a variable trial_number as a sequential number do that instead of using site_info.trial_number
+    if (add_sequential_trial_numbers) {
+      
+      message("Adding sequential trial numbers rather than using site_info.trial_number as the trial numbers")
+      
+    } else {
+      
+      raster_data <- raster_data |>
+        rename(trial_number = .data$site_info.trial_number) |>
+        select(.data$trial_number, everything())  
+    } 
+    
+  }
+  
+  
+
+  
   
   # change the class to be raster_data, data.frame
   attr(raster_data, "class") <- c("raster_data", "data.frame")
@@ -532,7 +555,7 @@ plot.raster_data <- function(x, ..., facet_label = NULL) {
   # check that indeed the data is in valid raster format
   test_valid_raster_format(raster_data)
   
-  activity_data_only_df <- raster_data %>%
+  activity_data_only_df <- raster_data |>
     dplyr::select(-starts_with("site_info"))
   
   # if there is not column called trial_number add it to the data
@@ -543,9 +566,9 @@ plot.raster_data <- function(x, ..., facet_label = NULL) {
 
   if (!(is.null(facet_label))) {
     
-    activity_data_only_df <- activity_data_only_df %>%
+    activity_data_only_df <- activity_data_only_df |>
       dplyr::select(starts_with(paste0("labels.", facet_label)), 
-                    starts_with("time"), starts_with("trial_number")) %>%
+                    starts_with("time"), starts_with("trial_number")) |>
       dplyr::rename(label = paste0("labels.", facet_label))
     
     
@@ -553,26 +576,26 @@ plot.raster_data <- function(x, ..., facet_label = NULL) {
     #  to be 1 to number trials for each label
     
     # first arrange the data so that it is in order of the original trial number
-    activity_data_only_df <- activity_data_only_df %>%
+    activity_data_only_df <- activity_data_only_df |>
       dplyr::arrange(.data$trial_number)
     
     # overwrite the trial number with trial numbers for each label
-    activity_data_only_df <- activity_data_only_df %>%
-      group_by(.data$label) %>%
+    activity_data_only_df <- activity_data_only_df |>
+      group_by(.data$label) |>
       mutate(trial_number = 1:n())
     
     
   } else {
-    activity_data_only_df <- activity_data_only_df %>%
+    activity_data_only_df <- activity_data_only_df |>
       dplyr::select(-starts_with("label"))
   }
   
   
 
   # convert to long format for plotting and time as a numeric value
-  activity_data_only_df <- activity_data_only_df %>%
-    tidyr::pivot_longer(starts_with("time"), names_to = "time", values_to = "activity") %>%   
-    dplyr::mutate(time = floor(get_center_bin_time(.data$time)))  
+  activity_data_only_df <- activity_data_only_df |>
+    tidyr::pivot_longer(starts_with("time"), names_to = "time", values_to = "activity") |>   
+    dplyr::mutate(time = floor(get_time_bin_center(.data$time)))  
 
   
   # if the data is a spike train of 0's and 1's
